@@ -32,7 +32,7 @@ int rawmode = 0, seq = 1, id = 0, num = 0;
 char hash[20] = "", *key = NULL, vec[8] = { 0, 0, 0, 0, 0, 0, 0, 0 };
 
 void help(char *prg) {
-  printf("%s %s (c) 2017 by %s %s\n\n", prg, VERSION, AUTHOR, RESOURCE);
+  printf("%s %s (c) 2018 by %s %s\n\n", prg, VERSION, AUTHOR, RESOURCE);
   printf("Syntax: %s [-k key] interface file\n\n", prg);
   printf("Options:\n");
   printf("  -k key     decrypt the content with Blowfish-160\n");
@@ -75,7 +75,7 @@ void check_packets(u_char *foo, const struct pcap_pkthdr *header, const unsigned
   dlen = 40 + (ptr[41] + 1) * 8;
   rlen = len - 54;
   pos = 54;
-  while (rlen > 0 && end == 0 && dlen >= pos && done == 0) {
+  while (rlen > 0 && end == 0 && dlen > pos && done == 0) {
     if (ptr[pos] == 0)
       done = 1;
     else if (ptr[pos] < 0x12)
